@@ -11,10 +11,10 @@ class tst_QLineSeries : public tst_QXYSeries
     Q_OBJECT
 
 public slots:
-    void initTestCase();
-    void cleanupTestCase();
-    void init();
-    void cleanup();
+    void initTestCase() override;
+    void cleanupTestCase() override;
+    void init() override;
+    void cleanup() override;
 private slots:
     void qlineseries_data();
     void qlineseries();
@@ -50,12 +50,17 @@ void tst_QLineSeries::cleanup()
 
 void tst_QLineSeries::qlineseries_data()
 {
+    QTest::addColumn<bool>("useOpenGL");
 
+    QTest::addRow("Without OpenGL") << false;
+    QTest::addRow("With OpenGL") << true;
 }
 
 void tst_QLineSeries::qlineseries()
 {
+    QFETCH(const bool, useOpenGL);
     QLineSeries series;
+    series.setUseOpenGL(useOpenGL);
 
     QCOMPARE(series.count(),0);
     QCOMPARE(series.brush(), QBrush());
